ConditionalInspector class

条件检查器组件 / Conditional inspector widget 根据编译模式自动决定是否显示检查器 / Automatically determine whether to show inspector based on build mode

在 release 模式下,此组件会返回空容器,检查器代码不会被打包 / In release mode, this widget returns an empty container, inspector code won't be bundled 在 debug/profile 模式下,会显示检查器按钮 / In debug/profile mode, inspector button will be shown

使用方式 / Usage:

Widget build(BuildContext context) {
  return ConditionalInspector(
    child: YourAppWidget(),
  );
}
Inheritance

Constructors

ConditionalInspector({Key? key, required Widget child, bool enabled = true})
const

Properties

child → Widget
子组件 / Child widget
final
enabled → bool
是否启用检查器(默认根据环境自动判断)/ Whether to enable inspector (auto-detect by environment by default)
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited